local options = {
	name = 'Sudoku by Strucker',
	type = 'group',
	desc = 'Sudoku! Play unique challenging Sudoku puzzles in WoW.',
	set = function(info,arg) Sudoku:SetOptionValue(info,arg) end,
	get = function(info) return Sudoku:GetOptionValue(info) end,
	handler = Sudoku,
	args = {
		["PUZZLE_FRAME"] = {
			name = "Puzzle Screen Settings",
			type = 'group',
			order = 100,
			guiInline = true,
			args = {
				
				["HIDE_IN_COMBAT"] = {
					name = "Hide in Combat",
					type = 'toggle',
					order = 100,
					arg = "hideInCombat",
					disabled = false,
				},
				["ANNOUNCE_NEW_RECORDS"] = {
					name = "Shout New Records",
					type = 'toggle',
					order = 150,
					arg = "announceNewRecords",
					disabled = false,
				},
				["PUZZLE_FRAME_SCALE"] = {
					name = "Puzzle Frame Scale",
					type = 'range',
					min = .1, max = 3, step = .1,
					order = 200,
					arg = "puzzleFrameScale"
				},
			}
		},
		
		["CREATE_FRAME"] = {
			name = "Puzzle Creation Settings",
			type = 'group',
			order = 200,
			guiInline = true,
			args = {
				["DIFFICULTY"] = {
					name = "Difficulty Mode",
					type = 'select',
					values = {[1]="Easy", [2]="Normal", [3]="Hard", [4]="Make Me Cry"},
					order = 50,
					arg = "mode",
					disabled = false,
				},
				["STEPS_PER_FRAME"] = {
					name = "Calc. Steps Per Frame",
					type = 'range',
					min = 5, max = 1000, step = 1,
					order = 100,
					arg = "stepsPerFrame"
				},
			}
		}
	}
}

local main

function Sudoku:RegisterOptions()
	local registry = LibStub('AceConfigRegistry-3.0')
	local dialog = LibStub('AceConfigDialog-3.0')
	LibStub('AceConfig-3.0'):RegisterOptionsTable('Sudoku', options, {'Sudoku', 'Sudoku'})
	
	registry:RegisterOptionsTable('Sudoku Options', options)
	main = dialog:AddToBlizOptions('Sudoku Options', 'Sudoku')
	local dataobj = LibStub:GetLibrary('LibDataBroker-1.1'):NewDataObject('Sudoku', {
		type = 'launcher',
		text = 'Sudoku',
		label = 'Sudoku',
		icon = 'Interface\\Icons\\Spell_Fire_Rune',
	})
	
	if dataobj then
		dataobj.OnClick = function(self,button,down) 
			if button == "RightButton" then
				Sudoku:ShowOptions()
			else
				if Sudoku:GetMenuFrame():IsVisible() then
					Sudoku:GetMenuFrame():Hide()
				else
					Sudoku:SlashCommand("")
				end
			end
		end
		dataobj.OnTooltipShow = function(tooltip)
			tooltip:AddLine('Sudoku by Strucker')
			tooltip:AddLine('Play unique challenging Sudoku puzzles in WoW.')
		end
		
		LibStub("LibDBIcon-1.0", true):Register("Sudoku", dataobj)
	end
end

function Sudoku:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(main) 
end
Sudoku:RegisterOptions()